@@ -55,17 +55,17 @@ class S3FileInput(ClearableFileInput):
 
     def value_from_datadict(self, data, files, name):
         url = data.get(name)
-        upload = files.get(name, False)
+        upload = files.get(name, None)
         if url:
             logger.info(url)
             if url == 'initial':
-                return None
+                return False
             filename = urllib2.unquote(urlparse(url).path)
             try:
                 f = default_storage.open(filename)
                 return f
             except IOError:
-                return False
+                return None
         return upload
 
     class Media:
